CelConstraint

Struct CelConstraint 

pub struct CelConstraint {
    pub id: &'static str,
    pub message: &'static str,
    pub expression: &'static str,
    /* private fields */
}

Fields

id: &'static strmessage: &'static strexpression: &'static str

Implementations

Source

impl CelConstraint

pub const fn new( id: &'static str, message: &'static str, expression: &'static str, ) -> Self

pub fn eval_value_at( &self, this: Value, field_path: FieldPath, cel_index: u64, ) -> Result<(), Violation>

Evaluates this CEL expression against this (bound as the this variable inside the expression) plus a per-call-frozen now timestamp.

Errors

Returns a Violation when the compiled CEL expression returns false, returns a non-empty string, or produces a runtime error.

Panics

Panics at first call if the CEL expression fails to compile (it is baked in at codegen time, so a parse failure indicates a plugin bug). Evaluate this CEL expression with this bound to the supplied raw crate::cel_core::Value (used for scalar-field-level CEL rules where the “this” target is a primitive, not a message). The violation’s field path is set from field_path and rule path is set to [cel[index]] reflecting position in the repeated FieldRules.cel.

pub fn eval_expr_value_at( &self, this: Value, field_path: FieldPath, index: u64, ) -> Result<(), Violation>

Like eval_value_at but for (field).cel_expression (string) constraints — the rule path uses field_number=29, field_name="cel_expression", field_type=String instead of cel’s field_number=23/field_type=Message.

Errors

Returns a Violation when the CEL expression rejects this.

pub fn eval_repeated_items_cel( &self, this: Value, field_path: FieldPath, cel_idx: u64, ) -> Result<(), Violation>

Evaluate for a repeated.items.cel[idx] rule. Rule path is [repeated(18), items(4), cel(23, index:cel_idx)].

Errors

Returns a Violation when the CEL expression rejects this.

pub fn eval_map_keys_cel( &self, this: Value, field_path: FieldPath, cel_idx: u64, ) -> Result<(), Violation>

map.keys.cel[idx]for_key=true.

Errors

Returns a Violation when the CEL expression rejects this.

pub fn eval_map_values_cel( &self, this: Value, field_path: FieldPath, cel_idx: u64, ) -> Result<(), Violation>

map.values.cel[idx].

Errors

Returns a Violation when the CEL expression rejects this.

pub fn eval_predefined( &self, this: Value, rule: Value, field_path: FieldPath, rule_path: FieldPath, ) -> Result<(), Violation>

Evaluate a predefined-rule CEL expression with this and rule bindings. Caller supplies the complete field_path and rule_path.

Errors

Returns a Violation when the CEL expression rejects this.

Panics

Panics if the CEL expression fails to compile (baked in at codegen time).

pub fn eval_value(&self, this: Value) -> Result<(), Violation>

Evaluate with this already bound as a raw CEL Value.

Errors

Returns a Violation when the CEL expression rejects this.

Panics

Panics if the CEL expression fails to compile (baked in at codegen time).

pub fn eval<T: AsCelValue>(&self, this: &T) -> Result<(), Violation>

Evaluate with this bound via the AsCelValue trait.

Errors

Returns a Violation when the CEL expression rejects this or when a non-skippable runtime error occurs.

Panics

Panics if the CEL expression fails to compile (baked in at codegen time).